django-tables2 - An app for creating HTML tables — django-tables2 2.0.0a3 documentation

# django-tables2 - An app for creating HTML tables

Its features include:

- Any iterable can be a data-source, but special support for Django QuerySets is included.
- The built in UI does not rely on JavaScript.
- Support for automatic table generation based on a Django model.
- Supports custom column functionality via subclassing.
- Pagination.
- Column based table sorting.
- Template tag to enable trivial rendering to HTML.
- Generic view mixin.

About the app:

- Available on pypi
- Tested with python 2.7, 3.4, 3.5, 3.6 and Django 1.11, Travis CI
- Documentation on readthedocs.org
- Bug tracker

## Table of contents

Getting started

- Installation
- Tutorial
- Populating a table with data

Customization

- Alternative column data
- Alternative column ordering
- Column and row attributes
- Customizing headers and footers
- Swapping the position of columns
- Pagination
- Table Mixins
- Customizing table style
- Query string fields
- Controlling localization
- Class Based Generic Mixins
- Pinned rows
- Filtering data in your table
- Exporting table data

Reference

- API
- FAQ
- Upgrading and change log
- Glossary